api library
Classes
- ApiClient
- ApiKeyAuth
- Authentication
- CreateMatchRequestBody
- CreateStateRequestBody
- DeserializationMessage
- Primarily intended for use in an isolate.
- HttpBasicAuth
- HttpBearerAuth
- Match
- MatchesApi
- MatchesOrderByEnum
- MatchesOrderByEnumTypeTransformer
- Transformation class that can encode an instance of MatchesOrderByEnum to String, and decode dynamic data back to MatchesOrderByEnum.
- MatchFormatEnum
- The rule to use for tiebreaks.
- MatchFormatEnumTypeTransformer
- Transformation class that can encode an instance of MatchFormatEnum to String, and decode dynamic data back to MatchFormatEnum.
- MatchPaginated
- MatchSummary
- OAuth
- ParticipantScore
- ParticipantSetSummary
- ProblemDetails
- QueryParam
- SetSummary
- State
- StatesApi
- UpdateStateRequestBody
Properties
- defaultApiClient ↔ ApiClient
-
getter/setter pair
Functions
-
deserializeAsync(
DeserializationMessage message) → Future - Primarily intended for use in an isolate.
-
mapCastOfType<
K, V> (dynamic map, String key) → Map< K, V> ? -
Returns a valid Map<K, V> found at the specified Map
key, null otherwise. -
mapDateTime(
dynamic map, String key, [String? pattern]) → DateTime? -
Returns a valid DateTime found at the specified Map
key, null otherwise. -
mapValueOfType<
T> (dynamic map, String key) → T? -
Returns a valid
Tvalue found at the specified Mapkey, null otherwise. -
parameterToString(
dynamic value) → String - Format the given parameter object into a String.
-
serializeAsync(
Object? value) → Future< String> - Primarily intended for use in an isolate.
Typedefs
- HttpBearerAuthProvider = String Function()